[java-idp-integration-tests] branch master updated: Set server startup wait time as a system property

Tom Zeller tzeller at dragonacea.biz
Sat Mar 24 21:04:08 EDT 2018


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch master
in repository java-idp-integration-tests.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-integration-tests.git;a=commit;h=7493ca8147f3d245a13c004fbf6eb64849a61d6c

The following commit(s) were added to refs/heads/master by this push:
       new  7493ca8   Set server startup wait time as a system property
7493ca8 is described below

commit 7493ca8147f3d245a13c004fbf6eb64849a61d6c
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Sat Mar 24 20:03:23 2018 -0500

    Set server startup wait time as a system property
---
 .../net/shibboleth/idp/test/AbstractServerProcess.java     | 14 +++++++++-----
 1 file changed, 9 insertions(+), 5 deletions(-)

diff --git a/src/test/java/net/shibboleth/idp/test/AbstractServerProcess.java b/src/test/java/net/shibboleth/idp/test/AbstractServerProcess.java
index f82b601..4bcc542 100644
--- a/src/test/java/net/shibboleth/idp/test/AbstractServerProcess.java
+++ b/src/test/java/net/shibboleth/idp/test/AbstractServerProcess.java
@@ -278,15 +278,19 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
     }
 
     /**
      * Wait up to 60 seconds for the IdP status page, trying every half-second.
      * 
      * @throws RuntimeException if the actual status page text is not expected
      * @throws Exception if an error occurs
      */
     public void waitForStatusPage() throws Exception {
-        log.debug("Waiting for server to start ...");
+        final String retries = System.getProperty("waitForStatusPage", "60");
+
+        log.debug("Waiting {} seconds for server to start ...", retries);
 
-        final String statusPageText = getStatusPageText(120, 500);
+        final String statusPageText = getStatusPageText(Integer.parseInt(retries), 1000);
 
         if (!statusPageText.startsWith(StatusTest.STARTS_WITH)) {
             log.error("Unable to determine if server has started.");
@@ -309,8 +313,8 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
 
         final HttpClientBuilder builder = new HttpClientBuilder();
         if (retries > 1) {
-            builder.setHttpRequestRetryHandler(new FiniteWaitHttpRequestRetryHandler(retries / 2, millis));
-            builder.setServiceUnavailableRetryHandler(new FiniteWaitServiceUnavailableRetryStrategy(retries / 2, millis));
+            builder.setHttpRequestRetryHandler(new FiniteWaitHttpRequestRetryHandler(retries, millis));
+            builder.setServiceUnavailableRetryHandler(new FiniteWaitServiceUnavailableRetryStrategy(retries, millis));
         }
         builder.setConnectionCloseAfterResponse(false);
         builder.setConnectionDisregardTLSCertificate(true);
@@ -278,15 +278,19 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
 
     /**
-     * Wait up to 60 seconds for the IdP status page, trying every half-second.
+     * Wait up to 60 seconds for the IdP status page, trying every second.
+     * 
+     * Set the 'waitForStatusPage' system property to change the maximum wait time.
      * 
      * @throws RuntimeException if the actual status page text is not expected

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list